Determine the groupings of values as they would be presented in the venn diagram.
Usage
calculate.overlap(x)
Value
Returns a list of lists which contain the values assigned to each of the areas of a venn diagram.
Arguments
x
A list of vectors (e.g., integers, chars), with each component corresponding
to a separate circle in the Venn diagram
Author
Christopher Lalansingh
Details
This function mostly complements the venn.diagram() function for the case where users
want to know what values are grouped into the particular areas of the venn diagram.