Usage
draw.triple.venn(area1, area2, area3, n12, n23, n13, n123, category = rep("", 3), rotation = 1, reverse = FALSE, euler.d = TRUE, scaled = TRUE, lwd = rep(2, 3),
lty = rep("solid", 3), col = rep("black", 3), fill = NULL, alpha = rep(0.5, 3), label.col = rep("black", 7), cex = rep(1, 7), fontface = rep("plain", 7),
fontfamily = rep("serif", 7), cat.pos = c(-40, 40, 180), cat.dist = c(0.05, 0.05, 0.025), cat.col = rep("black", 3), cat.cex = rep(1, 3), cat.fontface = rep("plain", 3),
cat.fontfamily = rep("serif", 3), cat.just = list(c(0.5, 1), c(0.5, 1), c(0.5, 0)), cat.default.pos = "outer", cat.prompts = FALSE, rotation.degree = 0,
rotation.centre = c(0.5, 0.5), ind = TRUE, sep.dist = 0.05, offset = 0, list.order = 1:3, ...)Arguments
area1
The size of the first set
area2
The size of the second set
area3
The size of the third set
n12
The size of the intersection between the first and the second set
n23
The size of the intersection between the second and the third set
n13
The size of the intersection between the first and the third set
n123
The size of the intersection between all three sets
category
A vector (length 3) of strings giving the category names of the sets
rotation
1 (default), 2, or 3 indicating clockwise rotation of the three sets from the default arrangement
reverse
Boolean indicating whether the diagram should be mirrored long the vertical axis or not
euler.d
Boolean indicating whether to draw Euler diagrams when conditions are met or not
scaled
Boolean indicating whether to scale circle sizes in certain Euler diagrams according to set sizes or not
lwd
A vector (length 3) of numbers giving the lwd of the circles' circumferences
lty
A vector (length 3) giving the lty of the circles' circumferences
col
A vector (length 3) giving the colours of the circles' circumferences
fill
A vector (length 3) giving the colours of the circles' areas
alpha
A vector (length 3) giving the alpha transparency of the circles' areas
label.col
A vector (length 7) giving the colours of the areas' labels
cex
A vector (length 7) giving the cex of the areas' labels
fontface
A vector (length 7) giving the fontface of the areas' labels
fontfamily
A vector (length 7) givibg the fontfamily of the areas' labels
cat.pos
A vector (length 3) giving the positions (in degrees) of the category names along the circles, with 0 (default) at the 12 o'clock location
cat.dist
A vector (length 3) giving the distances (in npc units) of the category names from the edges of the circles (can be negative)
cat.cex
A vector (length 3) giving the cex of the category names
cat.col
A vector (length 3) giving the colours of the category names
cat.fontface
A vector (length 3) giving the fontface of the category names
cat.fontfamily
A vector (length 3) giving the fontfamily of the category names
cat.just
List of 3 vectors of length 2 indicating horizontal and vertical justification of each category name
cat.default.pos
Either 'outer' or 'text' to specify the default location of category names (cat.pos and cat.dist are handled differently)
cat.prompts
Boolean indicating whether to display help text on category name positioning or not)
rotation.degree
Number of degrees to rotate the entire diagram
rotation.centre
A vector (length 2) indicating (x,y) of the rotation centre
ind
Boolean indicating whether the function is to automatically draw the diagram before returning the gList object or not
sep.dist
Number between 0 and 1 giving the distance between circles in certain Euler diagrams with mutually exclusive sets
offset
Number giving the amount of offset from the centre in certain Euler diagrams with inclusive sets
list.order
For internal use only
...
Additional arguments to be passed to or from other methods, including margin, which indicates amount of whitespace around the final diagram in npc units